#!/system/bin/sh
# Blacklist by 4non - January 2016
# denies all connections to big snifflers
# some rules taken from: github.com/ukanth/afwall/wiki/CustomScripts
# android-path: /system/su.d/ (SuperSu-Boot-Script)
####################################################

IPTABLES=/system/bin/iptables
IP6TABLES=/system/bin/ip6tables

# Wait until Startup-Leakage-Script finishes
$IPTABLES -A OUTPUT --wait
$IPTABLES -A INPUT --wait
$IPTABLES -A FORWARD --wait
$IP6TABLES -A OUTPUT --wait
$IP6TABLES -A INPUT --wait
$IP6TABLES -A FORWARD --wait

# Reset all Iptable rules
$IPTABLES -F
$IPTABLES -X
$IPTABLES -t nat -F
$IPTABLES -t nat -X
$IPTABLES -t mangle -F
$IPTABLES -t mangle -X
$IPTABLES -t raw -F
$IPTABLES -t raw -X
$IPTABLES -t security -F
$IPTABLES -t security -X
$IP6TABLES -F
$IP6TABLES -X
$IP6TABLES -t nat -F
$IP6TABLES -t nat -X
$IP6TABLES -t mangle -F
$IP6TABLES -t mangle -X
$IP6TABLES -t raw -F
$IP6TABLES -t raw -X
$IP6TABLES -t security -F
$IP6TABLES -t security -X

# Deny IPv6 connections
$IP6TABLES -P OUTPUT DROP
$IP6TABLES -P INPUT DROP
$IP6TABLES -P FORWARD DROP

############ Security-Iptable-Rules ############

# if you use VPN, Hotspot or Network,
# enable ip-forwarding and source-routing in sysctl.conf if disabled

# Force all traffic over VPN (on Wifi only) and drop them if there is no VPN
#$IPTABLES -A INPUT  -i tun0 -j ACCEPT
#$IPTABLES -A INPUT  -s 10.10.10.10 -j ACCEPT
#$IPTABLES -A OUTPUT -i tun0 -j ACCEPT
#$IPTABLES -A OUTPUT -d 10.10.10.10 -j ACCEPT
# For DNS whitelistening (if not already done)
#$IPTABLES -A OUTPUT -p udp --dport 53 -j ACCEPT
#$IPTABLES -A INPUT  -p udp --sport 53 -j ACCEPT

# Connect Wifi-Tethered Clients to VPN/Hotspots
#$IPTABLES -t filter -F FORWARD
#$IPTABLES -t nat -F POSTROUTING
#$IPTABLES -t filter -A FORWARD -j ACCEPT
#$IPTABLES -t nat -A POSTROUTING -j MASQUERADE

# Allow all apps access to standard Orbot ports
#$IPTABLES -A OUTPUT -d 127.0.0.1 -p tcp --dport 9040 -j ACCEPT
#$IPTABLES -A OUTPUT -d 127.0.0.1 -p udp --dport 5400 -j ACCEPT

# Allow all SSH(22)/HTTP(80)/HTTPS(443) connections on eth0 network
#$IPTABLES -A INPUT -i eth0 -p tcp -m multiport --dports 22,80,443 -m state --state NEW,ESTABLISHED -j ACCEPT
#$IPTABLES -A OUTPUT -o eth0 -p tcp -m multiport --sports 22,80,443 -m state --state ESTABLISHED -j ACCEPT
# Allow all Email connections on eth0: IMAP(143)/IMAPS(993)/ POP3(110)/POP3S(995)/SMTP(25/587)SMTPS(465)
#$IPTABLES -A INPUT -i eth0 -p tcp -m multiport --dports 143,993,110,995,25,587,465 -m state --state NEW,ESTABLISHED -j ACCEPT
#$IPTABLES -A OUTPUT -o eth0 -p tcp -m multiport --sports 143,993,110,995,25,587,465 -m state --state ESTABLISHED -j ACCEPT
# allow DNS on eth0 network:
#$IPTABLES -A OUTPUT -p udp -o eth0 --dport 53 -j ACCEPT
#$IPTABLES -A INPUT -p udp -i eth0 --sport 53 -j ACCEPT
# Note: remove above ports which you dont need, if you want to limit the input/OUTPUT rules on other networks,
# add for VPN "tun0", Cellular Network "rmnet0", WLAN "wlan0", etc. (also include "-p udp" rules! except for mail)

# Block normal Multicast-addresses
#$IPTABLES -A INPUT -s 224.0.0.0/4 -j DROP
#$IPTABLES -A INPUT -d 224.0.0.0/4 -j DROP
#$IPTABLES -A INPUT -s 240.0.0.0/5 -j DROP
#$IPTABLES -A INPUT -d 240.0.0.0/5 -j DROP
#$IPTABLES -A INPUT -s 0.0.0.0/8 -j DROP
#$IPTABLES -A INPUT -d 0.0.0.0/8 -j DROP
#$IPTABLES -A INPUT -d 239.255.255.0/24 -j DROP
#$IPTABLES -A INPUT -d 255.255.255.255 -j DROP

# Prevent SMURF attacks
$IPTABLES -A INPUT -p icmp -m icmp --icmp-type address-mask-request -j REJECT
$IPTABLES -A INPUT -p icmp -m icmp --icmp-type timestamp-request -j REJECT
$IPTABLES -A INPUT -p icmp -m limit --limit 2/second --limit-burst 2 -j DROP

# Prevent SYN attacks
$IPTABLES -A INPUT -p tcp --match recent --name TCP-PORTSCAN -j REJECT

# Block Shellshock
#$IPTABLES -A INPUT -m string --algo bm --hex-string '|28 29 20 7B|' -j DROP

# Block FTP connections
$IPTABLES -A INPUT -p tcp --dport 20:21 -j DROP
$IPTABLES -A OUTPUT -p tcp --sport 20:21 -j DROP

# Block SSH connections
$IPTABLES -A INPUT -p tcp --dport 22 -j DROP
$IPTABLES -A OUTPUT -p tcp --sport 22 -j DROP

# Block Telnet connections
$IPTABLES -A INPUT -p tcp --dport 23 -j DROP
$IPTABLES -A OUTPUT -p tcp --sport 23 -j DROP

############ ASN-Blacklist ############

# ASN-info: asnumbers.net // radb.net/query // bgp.he.net

#AS-GOOGLE/Gmail/Youtube/Playstore/etc.
#AS15169 (primary, Google Inc)
#AS36039 (Google Inc)
#AS36040 (Google Inc)
#AS36492 (Google Inc)
#AS16591 (Google Fiber)
#AS22577 (Google Admob)
#AS36384 (Google IT)
#AS41264 (Google Switzerland)
#AS43515 (Youtube Ireland)
#AS36561 (Youtube)
#AS36385 (Google Corp)
#AS26910 (Postini Inc)
#AS11344 (Metaweb Inc)
#AS40873 (Metaweb Inc)
#AS13949 (Slide Inc)
#AS55023 (TxVia Inc)
#AS19425 (ITA Software Inc)
$IPTABLES -A OUTPUT -d 1.0.0.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 1.1.1.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 1.2.3.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 8.6.48.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 8.8.4.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 8.8.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 8.15.202.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 8.34.208.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 8.35.192.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 12.216.80.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 23.228.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 23.236.48.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 23.251.128.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 23.255.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 45.56.0.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 45.121.228.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 46.28.247.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.9.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 64.15.112.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 64.18.0.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 64.79.152.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 64.233.160.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 65.221.113.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.102.0.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 66.249.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 70.32.128.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 72.14.192.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 74.114.24.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 74.125.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 89.207.224.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 99.198.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 103.62.64.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 104.132.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 104.154.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 104.196.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 104.237.160.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 107.167.160.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 107.178.192.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 107.188.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 108.59.80.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 108.170.192.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 108.177.0.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 113.197.104.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 130.211.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 136.32.0.0/11 -j REJECT
$IPTABLES -A OUTPUT -d 142.250.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 146.148.0.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 162.216.148.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 162.222.176.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 165.193.245.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 172.102.8.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 172.110.32.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 172.217.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 172.253.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 173.194.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 173.255.112.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 185.25.28.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 192.104.160.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 192.119.16.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 192.158.28.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 192.178.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 192.200.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 193.33.4.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 193.142.125.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 193.200.222.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 194.110.194.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 194.122.80.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 199.192.112.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 199.223.232.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 207.76.68.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 207.126.144.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 207.223.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 208.65.152.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.68.108.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.76.68.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.87.172.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.117.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 209.47.227.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.85.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 216.21.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 216.58.192.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 216.239.32.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 216.252.220.0/22 -j REJECT
# Note that a lot websites use googlerecaptcha for verifying,
# which probably dont works after applying the iptables above
# and no connect to googlesearch, youtube, gmail, playstore, etc
# but you can view for example google-blogs via ixquick-proxy

#AS-FACEBOOK
#AS32934 (primary, Facebook Inc)
#AS54115 (Facebook Inc)
#AS34825 (Onavo Ltd)
$IPTABLES -A OUTPUT -d 31.13.24.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 31.13.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 45.64.40.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 66.220.144.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 69.63.176.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 69.171.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 74.119.76.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 103.4.96.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 129.134.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 157.240.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 173.252.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 179.60.192.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 185.60.216.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 185.89.216.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 199.201.64.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 204.15.20.0/22 -j REJECT
#Facebook - Whatsapp/Instagram (Amazon Servers):
$IPTABLES -A OUTPUT -d 52.5.69.2/32 -j REJECT
$IPTABLES -A OUTPUT -d 52.0.227.212/32 -j REJECT
$IPTABLES -A OUTPUT -d 52.4.158.66/32 -j REJECT
$IPTABLES -A OUTPUT -d 54.164.44.207/32 -j REJECT
$IPTABLES -A OUTPUT -d 54.152.93.7/32 -j REJECT
$IPTABLES -A OUTPUT -d 54.88.91.235/32 -j REJECT
$IPTABLES -A OUTPUT -d 54.173.174.103/32 -j REJECT
$IPTABLES -A OUTPUT -d 107.21.4.179/32 -j REJECT
$IPTABLES -A OUTPUT -d 184.173.147.38/32 -j REJECT
$IPTABLES -A OUTPUT -d 184.173.147.39/32 -j REJECT
$IPTABLES -A OUTPUT -d 192.155.212.202/32 -j REJECT
$IPTABLES -A OUTPUT -d 192.155.212.203/32 -j REJECT

#AS-MICROSOFT/Bing/Hotmail/Skype/etc
#AS8075 (primary, Microsoft Corp)
#AS8068 (Microsoft Corp)
#AS8069 (Microsoft Corp)
#AS8070 (Microsoft Corp)
#AS8071 (Microsoft Corp)
#AS8072 (Microsoft Corp)
#AS8073 (Microsoft Corp)
#AS8074 (Microsoft Corp)
#AS3598 (Microsoft Corp)
#AS6584 (Microsoft Corp)
#AS20046 (Microsoft Corp)
#AS23468 (Microsoft Corp)
#AS62540 (Microsoft Corp)
#AS198015 (Microsoft Corp)
#AS198097 (Skype Communications)
$IPTABLES -A OUTPUT -d 8.6.176.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 13.64.0.0/11 -j REJECT
$IPTABLES -A OUTPUT -d 13.96.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 13.104.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 23.96.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 40.64.0.0/10 -j REJECT
$IPTABLES -A OUTPUT -d 51.8.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.10.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 51.12.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 51.18.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.51.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.53.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.103.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.104.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 51.107.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.116.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.120.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.124.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.132.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.136.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 51.138.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 51.140.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 51.144.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 52.96.0.0/12 -j REJECT
$IPTABLES -A OUTPUT -d 52.112.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 52.120.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 52.125.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 52.126.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 52.130.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 52.132.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 52.136.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 52.145.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 52.146.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 52.148.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 52.152.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 52.160.0.0/11 -j REJECT
$IPTABLES -A OUTPUT -d 52.224.0.0/11 -j REJECT
$IPTABLES -A OUTPUT -d 64.4.0.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 64.41.193.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 65.52.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 65.56.86.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 65.57.69.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 65.57.70.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 65.57.80.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 65.57.84.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 65.57.96.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 65.59.232.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 65.59.234.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 65.221.5.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.119.144.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 67.24.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 70.37.0.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 70.37.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 91.190.216.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 94.245.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 103.25.156.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 103.36.96.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 104.40.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 104.146.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 104.208.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 111.221.16.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 111.221.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 131.107.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.1.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.3.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.5.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.6.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.12.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.16.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.18.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.21.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.22.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.24.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.61.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.62.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 131.253.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 132.245.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 134.170.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 137.116.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 137.135.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 138.91.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 138.196.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 141.251.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 146.147.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 150.171.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 157.54.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 157.56.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 157.60.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 167.220.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 168.61.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 168.62.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 191.232.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 192.32.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 192.48.225.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.80.14.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.84.159.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.84.160.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 192.92.196.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.197.157.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 193.149.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 193.221.113.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 194.69.96.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 198.49.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.105.232.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 198.180.95.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.200.130.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.206.164.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 199.2.137.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 199.30.16.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 199.60.28.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 199.74.210.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 199.103.90.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 199.103.122.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 199.242.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 199.242.48.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 202.89.224.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 204.14.180.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.135.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.179.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.180.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.188.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.195.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.196.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.252.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.95.96.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 204.152.140.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.176.46.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.182.144.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.231.192.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.231.194.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.231.196.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 204.231.200.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 204.231.208.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 204.231.236.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.255.244.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 205.174.224.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 205.248.96.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 206.138.168.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 206.191.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 207.46.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 207.68.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 207.82.250.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 208.68.136.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 208.76.44.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.84.0.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 209.1.15.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.1.112.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 209.185.128.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 209.185.240.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 209.240.192.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 213.199.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 216.32.180.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.32.240.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.33.240.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.34.51.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.200.206.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.220.208.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 217.163.12.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 217.163.14.0/24 -j REJECT

#AS-YAHOO/Yahoosearch/Ymail/etc
#AS10310 (primary, Yahoo)
#AS5779 (Yahoo)
#AS2554 (Yahoo Japan Corp)
#AS4694 (Yahoo Japan Corp)
#AS7233 (Yahoo)
#AS7280 (Yahoo Inc)
#AS10880 (Yahoo)
#AS14678 (Yahoo)
#AS14776 (Yahoo Streaming)
#AS14778 (Inktomi Corp)
#AS15635 (Yahoo Europe)
#AS15896 (Yahoo Europe)
#AS17110 (Yahoo)
#AS22565 (Yahoo)
#AS23663 (Yahoo Bangalore NMC)
#AS23816 (Yahoo Japan Corp)
#AS24236 (Yahoo Bangalore NMC)
#AS24296 (Yahoo Japan Corp)
#AS24506 (Yahoo Taiwan)
#AS24572 (Yahoo Japan)
#AS26085 (Yahoo)
#AS26101 (Yahoo)
#AS28122 (Yahoo do Brasil Ltd)
#AS32116 (Yahoo)
#AS34010 (Yahoo Europe)
#AS34082 (Yahoo Europe)
#AS36129 (Yahoo)
#AS36646 (Yahoo)
#AS36647 (Yahoo)
#AS36752 (Yahoo)
#AS38689 (Yahoo Korea Corp)
#AS40986 (Yahoo Europe)
#AS42173 (Yahoo Europe)
#AS45501 (Yahoo Corp Network)
#AS45502 (Yahoo Corp Network)
#AS45863 (Yahoo India Pvt Ltd)
#AS45915 (Yahoo India Pvt Ltd)
#AS55416 (YAHOO KRA)
#AS55417 (YAHOO SGA)
#AS55418 (YAHOO ID1)
#AS55517 (YAHOO HKA)
#AS55898 (Yahoo Japan Corp)
$IPTABLES -A OUTPUT -d 8.3.34.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 8.8.178.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 8.12.145.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 8.12.146.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 8.12.148.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 12.17.123.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 14.137.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 27.123.36.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 27.123.39.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 27.123.48.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 27.123.198.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 46.228.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 61.115.228.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 61.115.234.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 61.115.238.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 61.195.160.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 61.206.32.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 61.206.36.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.163.102.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.250.192.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 64.58.76.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 64.156.215.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.157.4.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.209.232.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.94.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 66.163.160.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 66.196.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 66.218.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 66.228.176.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 67.28.112.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 67.72.118.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 67.195.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 68.142.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 68.180.128.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 68.180.160.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 68.180.192.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 69.147.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 72.30.0.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 72.30.36.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 72.30.40.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 72.30.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 72.30.96.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 72.30.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 74.6.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.0.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.192.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.208.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.224.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.244.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 76.13.248.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 77.238.160.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 87.248.96.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 98.136.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 103.2.72.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 103.2.244.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 103.8.48.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 111.67.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 114.110.48.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 114.111.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 114.141.40.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 115.178.0.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 116.214.0.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 117.104.188.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 117.104.190.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 118.151.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 119.161.0.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 124.83.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 124.108.76.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 124.108.100.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 124.147.32.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 154.34.224.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 164.46.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 170.118.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 180.222.100.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 180.233.112.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 182.22.0.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 183.79.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 183.177.68.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 183.177.80.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 184.165.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 188.125.64.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 188.125.80.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 188.125.88.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 188.125.92.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 188.125.94.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 192.218.8.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 193.93.196.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 194.88.69.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 195.50.88.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 195.50.106.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.183.134.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 198.183.136.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 200.152.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 202.4.164.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.46.19.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.47.143.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.89.120.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 202.93.6.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.93.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 202.165.108.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.171.234.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.1.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.2.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.32.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.48.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.78.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.108.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.118.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.135.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.152.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.160.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.224.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 202.218.252.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 202.228.192.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.228.197.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.228.204.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 202.228.230.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.228.233.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 202.239.0.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.14.212.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.83.248.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 203.84.192.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 203.95.16.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.110.236.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 203.137.0.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 203.137.80.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.137.96.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.137.112.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.141.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.141.54.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.145.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.0.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.16.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.30.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.52.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.56.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.112.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.200.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.208.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.216.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.228.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 203.183.240.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.188.192.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 203.216.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 204.71.177.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.71.188.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.71.200.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 205.172.212.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 206.173.250.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 206.190.32.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 208.67.64.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 208.71.40.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 208.178.111.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.1.224.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 209.73.160.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 209.131.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 209.131.56.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 209.131.60.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 209.225.40.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.247.158.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 210.152.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 210.156.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 210.168.96.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 210.171.32.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 210.189.84.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 210.229.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 210.239.33.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 210.239.61.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 210.250.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 210.252.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 211.10.10.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 211.10.17.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 211.14.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 211.14.12.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 211.14.20.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 211.14.26.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 211.14.28.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 211.14.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 211.133.130.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 211.133.132.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 211.133.134.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 211.133.139.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 211.133.143.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 212.82.96.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 216.39.48.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 216.48.68.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.109.112.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 216.115.96.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.128.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.172.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.203.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.204.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.220.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.224.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.136.232.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.155.192.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 216.252.96.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 217.12.0.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 217.146.176.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 217.163.20.0/23 -j REJECT
#Tumblr (Yahoo-Blogs): AS33612
#$IPTABLES -A OUTPUT -d 66.6.32.0/20 -j REJECT

#AS-APPLE:
#AS714 (primary, Apple Inc)
#AS6185 (Apple Inc)
$IPTABLES -A OUTPUT -d 17.0.0.0/8 -j REJECT
$IPTABLES -A OUTPUT -d 192.35.50.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.183.16.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 204.79.190.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.179.120.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 205.180.175.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.144.162.0/24 -j REJECT

#Adobe:
#AS15224 (primary, Adobe Systems Inc)
#AS1313 (Adobe Systems Inc)
#AS14365 (Adobe Systems Inc)
#AS22786 (Adobe Systems Inc)
#AS44786 (Adobe Systems Ireland Ltd)
$IPTABLES -A OUTPUT -d 63.140.32.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 64.0.192.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 64.124.203.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.124.231.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.117.16.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 66.235.128.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 67.105.198.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 70.42.13.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 130.248.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 153.32.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 185.34.188.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 192.147.117.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.147.118.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 192.147.120.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.147.124.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.147.128.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.1.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.2.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.4.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.8.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.16.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.20.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.150.23.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.243.224.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 192.243.248.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 193.104.215.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 193.105.139.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 193.105.140.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 195.35.86.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 195.50.75.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.72.192.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 207.108.181.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 208.67.40.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 208.67.42.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 208.77.136.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.84.132.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.91.168.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 216.104.208.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 216.104.214.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 216.104.216.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 216.104.220.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.104.223.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.143.122.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 216.194.125.0/24 -j REJECT

#AS-AOL:
#AS1668 (primary, AOL TDN)
#AS6432 (Doubleclick)
#AS4393 (Time Inc)
#AS5662 (TB System)
#AS5686 (AOL CTC)
#AS6992 (AOL NETCENTER)
#AS8939 (AOL Adtech-DE)
#AS11631 (AOL ptne1-dc3)
#AS12039 (Time Inc)
#AS14853 (AOL HKA)
#AS14854 (AOL ptne1-mc1)
#AS14855 (AOL wc1-mtc)
#AS19137 (AOL Epsilon Interactive)
#AS25723 (AOLTW-WMG-DE)
#AS25802 (AOL HBO)
#AS36032 (Warner Brothers)
#AS36168 (Bebo Inc)
#AS40703 (TB System)
$IPTABLES -A OUTPUT -d 62.51.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 62.78.0.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 62.221.20.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.12.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 64.236.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 65.205.129.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.7.58.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.61.144.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 66.150.94.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.185.128.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 89.167.233.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 93.191.144.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 93.191.150.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 142.54.254.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 146.82.220.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 149.93.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 149.174.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 152.163.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.128.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.152.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.183.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.191.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.215.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.216.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.218.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.222.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 157.166.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 159.127.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.0.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.96.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.192.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.200.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.204.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.206.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.210.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.216.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 168.161.228.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 172.128.0.0/10 -j REJECT
$IPTABLES -A OUTPUT -d 172.200.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 172.208.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 178.237.25.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 194.117.224.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 194.126.131.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 194.126.132.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 195.93.0.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 198.31.62.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 198.81.0.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 198.81.230.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.95.248.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 198.178.157.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.190.122.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.140.0.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.140.3.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.140.5.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.140.6.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.140.8.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.140.10.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 205.188.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 206.208.176.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 206.208.178.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.208.180.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 206.208.182.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.222.224.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 206.253.180.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.253.184.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 207.7.149.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 207.7.150.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 207.200.64.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 208.70.136.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.70.140.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 208.75.184.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 208.160.209.32/27 -j REJECT
$IPTABLES -A OUTPUT -d 208.160.209.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 208.211.225.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.62.176.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 209.251.200.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 209.251.208.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 216.73.80.0/20 -j REJECT

#Dropbox:
#AS19679 (primary, Dropbox Inc)
#AS54372 (Dropbox Inc)
#AS62190 (Dropbox Inc)
$IPTABLES -A OUTPUT -d 45.58.64.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 108.160.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 185.45.8.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 185.105.164.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 192.189.200.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 199.47.216.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 205.189.0.0/24 -j REJECT

#AS-TWITTER: (optional)
#AS13414 (primary, Twitter Inc)
#AS35995 (Twitter Inc)
#AS54888 (Twitter Inc)
#AS63179 (Mopub Inc)
#$IPTABLES -A OUTPUT -d 8.25.194.0/23 -j REJECT
#$IPTABLES -A OUTPUT -d 8.25.196.0/23 -j REJECT
#$IPTABLES -A OUTPUT -d 69.12.56.0/21 -j REJECT
#$IPTABLES -A OUTPUT -d 103.252.112.0/22 -j REJECT
#$IPTABLES -A OUTPUT -d 104.244.40.0/21 -j REJECT
#$IPTABLES -A OUTPUT -d 185.45.4.0/22 -j REJECT
#$IPTABLES -A OUTPUT -d 192.44.68.0/23 -j REJECT
#$IPTABLES -A OUTPUT -d 192.48.236.0/23 -j REJECT
#$IPTABLES -A OUTPUT -d 192.133.76.0/22 -j REJECT
#$IPTABLES -A OUTPUT -d 199.16.156.0/22 -j REJECT
#$IPTABLES -A OUTPUT -d 199.59.148.0/22 -j REJECT
#$IPTABLES -A OUTPUT -d 199.96.56.0/21 -j REJECT
#$IPTABLES -A OUTPUT -d 202.160.128.0/22 -j REJECT

#AS-AKAMAI
#AS20940 (primary, Akamai International B.V.)
#AS21342 (Akamai International B.V.)
#AS21399 (Akamai International B.V.)
#AS31107 (Akamai International B.V.)
#AS31108 (Akamai International B.V.)
#AS31109 (Akamai International B.V.)
#AS31110 (Akamai International B.V.)
#AS31377 (Akamai International B.V.)
#AS39836 (Akamai International B.V.)
#AS21357 (Akamai International B.V.)
#AS21399 (Akamai International B.V.)
#AS33905 (Akamai International B.V.)
#AS34164 (Akamai International B.V.)
#AS34850 (Akamai International B.V.)
#AS35204 (Akamai International B.V.)
#AS43639 (Akamai International B.V.)
#AS12222 (Akamai Technologies Inc)
#AS16702 (Akamai Technologies Inc)
#AS18680 (Akamai Technologies Inc)
#AS35994 (Akamai Technologies Inc)
#AS23903 (Akamai Technologies Inc)
#AS35993 (Akamai Technologies Inc)
#AS24319 (Akamai Technologies Tokyo)
#AS16625 (Akamai Technologies European)
#AS18717 (Akamai - Chicago)
#AS20189 (Akamai - San Jose)
#AS23454 (Akamai - LGA2)
#AS22207 (Akamai - CLV)
#AS23455 (Akamai - SEA)
$IPTABLES -A OUTPUT -d 2.16.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 4.77.205.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 23.0.0.0/12 -j REJECT
$IPTABLES -A OUTPUT -d 23.32.0.0/11 -j REJECT
$IPTABLES -A OUTPUT -d 23.64.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 23.72.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 23.192.0.0/11 -j REJECT
$IPTABLES -A OUTPUT -d 38.113.220.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 41.193.163.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 43.254.120.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 59.151.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 60.254.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 63.84.59.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.85.36.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.116.109.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.119.76.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.126.84.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.141.194.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 63.141.196.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 63.146.70.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.150.12.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.208.195.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.210.173.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.215.198.96/32 -j REJECT
$IPTABLES -A OUTPUT -d 63.217.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.217.232.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 63.233.60.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 64.86.132.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.124.187.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.124.214.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.125.118.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 64.157.40.192/26 -j REJECT
$IPTABLES -A OUTPUT -d 64.208.48.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 64.208.187.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 64.212.114.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 65.19.187.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 65.202.32.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 66.160.145.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.171.231.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 66.198.8.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 66.220.21.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 67.131.232.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 69.26.179.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 69.26.180.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 69.27.160.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 69.31.20.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 69.31.21.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 69.31.106.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 69.31.119.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 69.45.79.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 69.45.84.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 69.45.86.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 69.192.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 70.39.139.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 72.246.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 80.67.64.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 81.20.72.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 81.25.198.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 81.25.206.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 81.93.191.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 81.93.208.0/26 -j REJECT
$IPTABLES -A OUTPUT -d 82.112.106.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 83.217.226.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 84.24.64.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 84.53.128.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 88.221.0.0/16 -j REJECT
$IPTABLES -A OUTPUT -d 92.122.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 95.100.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 96.6.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 96.16.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 103.238.148.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 104.64.0.0/10 -j REJECT
$IPTABLES -A OUTPUT -d 110.164.15.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 118.214.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 121.78.191.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 122.252.32.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 122.252.128.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 124.155.192.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 125.56.128.0/17 -j REJECT
$IPTABLES -A OUTPUT -d 125.252.192.0/18 -j REJECT
$IPTABLES -A OUTPUT -d 128.241.89.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 128.241.91.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 128.241.221.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 146.82.98.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 157.238.74.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.1.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.27.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.32.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.40.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.52.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.94.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.99.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.127.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.133.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.137.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.156.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.158.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.159.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.202.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.202.128/26 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.204.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 165.254.245.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 166.90.150.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 166.90.208.166/32 -j REJECT
$IPTABLES -A OUTPUT -d 168.143.240.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 172.224.0.0/12 -j REJECT
$IPTABLES -A OUTPUT -d 172.247.176.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 173.222.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 182.50.0.0/19 -j REJECT
$IPTABLES -A OUTPUT -d 182.50.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 184.24.0.0/13 -j REJECT
$IPTABLES -A OUTPUT -d 184.46.152.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 184.50.0.0/15 -j REJECT
$IPTABLES -A OUTPUT -d 184.84.0.0/14 -j REJECT
$IPTABLES -A OUTPUT -d 184.214.32.0/20 -j REJECT
$IPTABLES -A OUTPUT -d 190.2.175.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.70.222.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.204.3.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 192.204.4.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 193.108.88.0/21 -j REJECT
$IPTABLES -A OUTPUT -d 193.108.152.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 195.57.81.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 195.57.152.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 195.95.192.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 195.245.124.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 198.47.108.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 198.87.51.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.93.38.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 198.144.112.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 199.48.106.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 200.136.36.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 201.220.10.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.25.23.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.30.14.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.31.242.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.63.146.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.69.138.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.69.141.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 203.221.109.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.0.54.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.2.148.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 204.2.163.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 204.2.187.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.2.199.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.2.215.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.8.48.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 204.10.28.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 204.93.46.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 204.245.23.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 204.245.143.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 204.245.152.64/26 -j REJECT
$IPTABLES -A OUTPUT -d 204.245.190.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 204.246.230.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.55.4.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 206.57.28.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.132.122.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 206.161.222.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 206.239.100.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 207.126.107.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 207.151.118.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 208.48.0.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 209.249.114.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 210.8.28.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 210.9.71.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 210.9.135.192/26 -j REJECT
$IPTABLES -A OUTPUT -d 210.11.208.0/22 -j REJECT
$IPTABLES -A OUTPUT -d 210.11.212.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 210.61.248.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 211.175.153.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 212.119.27.0/25 -j REJECT
$IPTABLES -A OUTPUT -d 213.198.95.128/25 -j REJECT
$IPTABLES -A OUTPUT -d 213.198.96.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.156.213.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.156.242.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.187.88.0/23 -j REJECT
$IPTABLES -A OUTPUT -d 216.200.69.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.206.12.128/26 -j REJECT
$IPTABLES -A OUTPUT -d 216.206.30.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 216.218.251.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 219.76.11.0/24 -j REJECT
$IPTABLES -A OUTPUT -d 219.76.14.0/26 -j REJECT
